@@ -212,7 +212,7 @@ function(x, y, fun=NULL, method="simple", list=FALSE, factors=TRUE, cells=FALSE,
 			} else {
 				bad <- TRUE
 			}
-			if (bad) error("extract", 'if weights or exact=TRUE, "fun" must be "sum", "mean" or NULL')
+			if (bad) error("extract", 'if weights or exact=TRUE, "fun" must be "sum", "mean", "min", or "max"')
 		}
 	} 
 	if (!is.null(layer) && nl > 1) {
@@ -456,7 +456,7 @@ function(x, i, j, ... , drop=TRUE) {
 	} else if (ncol(i) == 2) {
 		i <- cellFromXY(x, i)
 	} else {
-		error(" [", "cannot extract values with a matrix of these dimensions")
+		error(" [", "cannot extract values with a ` of these dimensions")
 	}
 	`[`(x, i, drop=drop)
 })
@@ -521,8 +521,11 @@ function(x, i, j, ..., drop=FALSE) {
 
 setMethod("extract", c("SpatVector", "SpatVector"),
 function(x, y, ...) {
-	r <- relate(y, x, "within")
-	e <- apply(r, 1, which)
+
+	#r <- relate(y, x, "within")
+	#e <- apply(r, 1, which)
+	r <- relate(x, y, "covers")
+	e <- apply(r, 2, which)
 	if (length(e) == 0) {
 		e <- list(e)
 	}
